@@ -2,13 +2,13 @@ use strict;
 use warnings;
 package SQL::SplitStatement;
 
-our $VERSION = '1.00021'; # TRIAL
+our $VERSION = '1.00022'; # TRIAL
 
 
 use base 'Class::Accessor::Fast';
 
 use Carp qw(croak);
-use SQL::Tokenizer 0.22 qw(tokenize_sql);
+use SQL::SplitStatement::Tokenizer qw(tokenize_sql);
 use List::MoreUtils qw(firstval firstidx each_array);
 use Regexp::Common qw(delimited);
 
@@ -62,7 +62,7 @@ my $IS_RE                 = qr/^IS$/i;
 my $TYPE_RE               = qr/^TYPE$/i;
 my $BODY_RE               = qr/^BODY$/i;
 my $DROP_RE               = qr/^DROP$/i;
-my $CRUD_RE               = qr/^(?:DELETE|INSERT|SELECT|UPDATE)$/i;
+my $CRUD_RE               = qr/^(?:DELETE|INSERT|SELECT|UPDATE|REPLACE)$/i;
 
 my $GRANT_REVOKE_RE       = qr/^(?:GRANT|REVOKE)$/i;;
 my $CREATE_ALTER_RE       = qr/^(?:CREATE|ALTER)$/i;
@@ -1229,10 +1229,6 @@ You can also look for information at:
 
 =over 4
 
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=SQL-SplitStatement>
-
 =item * AnnoCPAN: Annotated CPAN documentation
 
 L<http://annocpan.org/dist/SQL-SplitStatement>
@@ -1241,9 +1237,9 @@ L<http://annocpan.org/dist/SQL-SplitStatement>
 
 L<http://cpanratings.perl.org/d/SQL-SplitStatement>
 
-=item * Search CPAN
+=item * On MetaCPAN
 
-L<http://search.cpan.org/dist/SQL-SplitStatement/>
+L<https://metacpan.org/pod/SQL::SplitStatement/>
 
 =back
 
